@@ -22,8 +22,7 @@ pd.set_option('display.max_rows', 100)
 @click.command()
 @click.option('--input-path', '-in', required=True, type=click.Path(), prompt=cal.title(),
               help="Path to input archive or PDF directory", show_choices=False)
-@click.option('--output-path', '-out', prompt=cal.both(), required=True, type=click.Path(),
-              help="Path to output table (.xls, .xlsx, .csv, .json, .dta) or archive (.pkl.xz, .json.zip, .parquet)", show_choices=False)
+@click.option('--output-path', '-out', required=True, type=click.Path(), prompt=cal.both(), help="Path to output table (.xls, .xlsx, .csv, .json, .dta) or archive (.pkl.xz, .json.zip, .parquet)")
 @click.option('--table', '-t', help="Table export choice (cases, fees, charges, disposition, filing, or all)")
 @click.option('--archive', '-a', is_flag=True, help="Create full text archive at output path")
 @click.option('--count', '-c', default=0, help='Total cases to pull from input', show_default=False)
@@ -35,19 +34,23 @@ pd.set_option('display.max_rows', 100)
 @click.option('--no-log','-q','log', default=False, is_flag=True, help="Don't print logs or progress to console")
 @click.option('--no-write','-n', default=False, is_flag=True, help="Do not export to output path", hidden=True)
 @click.option('--no-prompt', '-p', default=False, is_flag=True, help="Skip user input / confirmation prompts")
-@click.option('--debug','-d', default=False, is_flag=True, help="Prints extensive logs to console for development purposes")
+@click.option('--debug','-d', default=False, is_flag=True, help="Print extensive logs to console for developers")
 @click.option('--no-batch','-b', default=False, is_flag=True, help="Process all inputs as one batch")
 def cli(input_path, output_path, count, table, archive, overwrite, launch, dedupe, log, no_write, no_prompt, debug, no_batch,
         compress):
-    show_options_menu = True if table is None and no_prompt == False and count == 0 and overwrite == False and launch == False and dedupe == False and log == True and no_write == False and no_prompt == False and debug == False and no_batch == False else False
 
     log = not log 
 
+    show_options_menu = True if table is None and no_prompt == False and count == 0 and overwrite == False and launch == False and dedupe == False and log == True and no_write == False and no_prompt == False and debug == False and no_batch == False and compress == False else False
+
     # suppress tracebacks unless debug
     if not debug:
         sys.tracebacklimit = 0
         warnings.filterwarnings('ignore')
 
+    # fix double zip
+    output_path = output_path.replace(".zip","")
+
     # inputs - configure and log
     inputs = cal.setinputs(input_path)
     if debug:
@@ -97,7 +100,7 @@ def cli(input_path, output_path, count, table, archive, overwrite, launch, dedup
             else:
                 raise Exception("Invalid table selection!")
 
-    if outputs.MAKE == "archive":
+    if outputs.MAKE == "archive" or archive == True:
         compress = True
 
     # prompt options
